@@ -4,7 +4,7 @@
 
 from __future__ import absolute_import
 
-__author__ = """Jin Hyun Cheong, Tiankang Xie, Sophie Byrne, Nathaniel Hanes, Luke Chang """
+__author__ = """Jin Hyun Cheong, Tiankang Xie, Sophie Byrne, Luke Chang """
 __email__ = 'jcheong0428@gmail.com'
 __all__ = ['detector', 'data','utils','plotting','__version__']
 
